@@ -1,10 +1,11 @@
 import os
 import sys
 
-from git import InvalidGitRepositoryError, Repo
-
-from shulkr import create_version
+from shulkr import create_gitignore, create_version
+from shulkr.config import get_config
 from shulkr.arguments import parse_args
+from shulkr.git import head_has_versions
+from shulkr.minecraft.source import detect_mappings
 from shulkr.minecraft.version import NoSuchVersionError, Version, load_manifest
 
 
@@ -13,11 +14,23 @@ def main_uncaught() -> None:
 
 	args = parse_args(sys.argv[1:])
 
-	repo_path = os.path.join(
+	config = get_config()
+
+	config.repo_path = os.path.join(
 		os.getcwd(),
 		args.repo
 	)
 
+	if args.mappings is None:
+		if head_has_versions():
+			# Use mappings from previous version
+			config.mappings = detect_mappings()
+		else:
+			# Use default
+			config.mappings = 'yarn'
+	else:
+		config.mappings = args.mappings
+
 	try:
 		versions = Version.patterns(args.version)
 	except NoSuchVersionError as e:
@@ -31,20 +44,18 @@ def main_uncaught() -> None:
 		print('No versions selected', file=sys.stderr)
 		sys.exit(3)
 
-	if not os.path.exists(repo_path):
-		print(f'Creating {repo_path}')
-		os.mkdir(repo_path)
+	if not os.path.exists(config.repo_path):
+		print(f'Creating {config.repo_path}')
+		os.mkdir(config.repo_path)
 
-	try:
-		repo = Repo(repo_path)
-	except InvalidGitRepositoryError:
-		print('Initializing git')
-		repo = Repo.init(repo_path)
+	gitignore = os.path.join(config.repo_path, '.gitignore')
+	if not os.path.isfile(gitignore):
+		create_gitignore()
 
 	for version_id in versions:
 		create_version(
-			repo,
 			version_id,
+			args.mappings,
 			args.undo_renamed_vars,
 			args.message,
 			args.tag
