@@ -8,6 +8,13 @@ def parse_args(args: List[str]) -> argparse.Namespace:
 		description='Generate multiple versions of the Minecraft source code'
 	)
 
+	parser.add_argument(
+		'--mappings',
+		type=str,
+		required=False,
+		help='Mappings for deobfuscation, mojang or yarn (default)'
+	)
+
 	parser.add_argument(
 		'--repo',
 		'-p',
